@@ -15,7 +15,7 @@
 # Licenced under GPLv2
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '1.8-1'
+Version = '1.9-1'
 
 # TODO:
 # * find a better solution for gobject segmentation fault.
@@ -232,14 +232,16 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
       
        #Connect the GUI Buttons with actions
-       ##Create application buttons
+       ##Application buttons
        QtCore.QObject.connect(self.ui.btnGetCellIDon, QtCore.SIGNAL('clicked()'), self.doTrackOn)
        QtCore.QObject.connect(self.ui.btnGetCellIDoff, QtCore.SIGNAL('clicked()'), self.doTrackOff)
        QtCore.QObject.connect(self.ui.btnSeeMap, QtCore.SIGNAL('clicked()'), self.doSeeMap)
        QtCore.QObject.connect(self.ui.btnGoogleMaps, QtCore.SIGNAL('clicked()'), self.doOpenGoogleMaps)
-       ##Create application button - edit mode 
+       ##Application button - edit mode 
        # QtCore.QObject.connect(self.ui.btnGetLocation, QtCore.SIGNAL('clicked()'), self.doGetLocation)
        # QtCore.QObject.connect(self.ui.btnGetCellID, QtCore.SIGNAL('clicked()'), self.doGetCellID)
+       ##Application buttons - checkbox
+       QtCore.QObject.connect(self.ui.checkBoxGetLocation, QtCore.SIGNAL('clicked()'), self.GetLocationToggled)
       
        ##Connect Menu Buttons 
        QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
@@ -304,30 +306,42 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
        gobject.MainLoop().quit()
                     
     def ReceiverSet(self):
-          '''Setup the change of cell info signal receiver'''
-          bus = dbus.SystemBus()
-          # bus.add_signal_receiver(self.doGetCellID, 
-          bus.add_signal_receiver(self.received_cellid_info, 
-                                  path           = '/com/nokia/phone/net',
-                                  dbus_interface = 'Phone.Net',
-                                  signal_name    = 'registration_status_change')
-          print bus  
+       '''Setup the change of cell info signal receiver'''
+       bus = dbus.SystemBus()
+       # bus.add_signal_receiver(self.doGetCellID, 
+       bus.add_signal_receiver(self.received_cellid_info, 
+                               path           = '/com/nokia/phone/net',
+                               dbus_interface = 'Phone.Net',
+                               signal_name    = 'registration_status_change')
+       print bus  
 
     def ReceiverUnSet(self):
-          '''Unset the change of cell info signal receiver'''
-          bus = dbus.SystemBus()
-          # bus.remove_signal_receiver(self.doGetCellID, 
-          bus.remove_signal_receiver(self.received_cellid_info, 
-                                  path           = '/com/nokia/phone/net',
-                                  dbus_interface = 'Phone.Net',
-                                  signal_name    = 'registration_status_change')
-          print bus  
+       '''Unset the change of cell info signal receiver'''
+       bus = dbus.SystemBus()
+       # bus.remove_signal_receiver(self.doGetCellID, 
+       bus.remove_signal_receiver(self.received_cellid_info, 
+                               path           = '/com/nokia/phone/net',
+                               dbus_interface = 'Phone.Net',
+                               signal_name    = 'registration_status_change')
+       print bus  
+    
+    def GetLocationToggled(self):
+       
+       MCC    = int(self.ui.lineMCC.text())
+       MNC    = int(self.ui.lineMNC.text()) 
+       LAC    = int(self.ui.lineLAC.text())
+       CELLID = int(self.ui.lineCellID.text())
+
+       if self.ui.checkBoxGetLocation.isChecked() == True:
+          self.doGetLocation(MCC,MNC,LAC,CELLID)
+       else:
+          pass
        
     ##Create Methods
     def doAbout(self):
     
-         stackwindow = snuggleAbout(self)
-         stackwindow.show()
+       stackwindow = snuggleAbout(self)
+       stackwindow.show()
 
     def doEnableEditMode(self):
     
